@@ -1,23 +1,40 @@
+"""
+Tools for attaching models?
+"""
+
 from ...imports import *
 
+__all__ = ["attach_model"]
+
 
 def attach_model(self, model, **kw):
     """
-    Attach a fluxlike model to this Rainbow,
-    storing it as `self.fluxlike['model']`
+    Attach a `fluxlike` model, thus making a new `RainbowWithModel.`
 
-    After running this once, it's OK (and faster) to simply
-    update the `.model` attribute of the result.
+    Having a model attached makes it possible to make calculations
+    (residuals, chi^2) and visualizations comparing data to model.
+
+    The `model` array will be stored in `.fluxlike['model']`.
+    After running this to make a `RainbowWithModel` it's OK
+    (and faster) to simply update `.fluxlike['model']` or `.model`.
 
     Parameters
     ----------
-    model : np.array, u.Quantity
+    model : array, Quantity
         An array of model values, with the same shape as 'flux'
-    kw : dict
+    **kw : dict, optional
         All other keywords will be interpreted as items
-        that can be added to a Rainbow. You might use this
-        to attach intermediate model steps or quantities
-        (for example, 'planet_model' or 'systematics_model').
+        that can be added to a `Rainbow`. You might use this
+        to attach intermediate model steps or quantities.
+        Variable names ending with `_model` can be particularly
+        easily incorporated into multi-part model visualizations
+        (for example, `'planet_model'` or `'systematics_model'`).
+
+
+    Returns
+    -------
+    rainbow : RainbowWithModel
+        A new `RainbowWithModel` object, with the model attached.
     """
 
     # create a history entry for this action (before other variables are defined)
